@@ -26,12 +26,21 @@ def start_wqrfproxy(port='8000',client_certs=''):
     print(u"*** 你可以用 assert_proxy(目标url,预期字符串) 方法来断言设备发出的请求 you can use assert_proxy(your url,your reuqest content) to assert the http ***")
     print(u"*** url必须像这样 http(s)://xxxxx....，并且只能填入 '?' 之前的部分 the url must like http(s)://xxxxx.... which piece befor '?' ***")
     print(u"*** 这个预期字符串将会在url参数部分和请求体中进行查找 the request content will be found in url's params and request's body ***")
+    print(u"*** 抓包过程中的日志文件可能会非常庞大,您可以用clear_log()方法来及时清理,但注意断言是需要该日志文件的,所以请在每条用例结束后调用clear_log(),如uniitest的tearDown方法内 ***")
+    print(u"*** The log.txt will be very large in the process,so you can use clear_log() to free it,but it must called after the assert,better after the case,like in unittet's tearDown() ***")
     print(u"*** 你最好在你的脚本结尾写上 stop_wqrfproxy() 函数用来关闭服务 you'd better write stop_wqrfproxy() in your script's end to close the server ***")
     print(u'*** 您可以访问http://....... 来阅读使用教程和demo you can find help in http://....... ***')
     print(u'*** 您也可以发送邮件至1074321997@qq.com来获取帮助 you can also send mail to 1074321997@qq.com for help ***')
     print('*** -------------------------------------------------------------------- ***')
     time.sleep(3)
 
+
+# 清除释放log.txt
+def clear_log():
+    os.remove('log.txt')
+    with open('log.txt','w') as fp:
+        fp.write('{}')
+
 #  获取服务器ip：
 def get_ip():
     try:
@@ -84,4 +93,4 @@ def assert_proxy(url='',content=''):
                 raise AssertionError(u"*** 只找到url但未发现预期字符串！ It has been found the url,but can't find the reuqest body! ***")
         except KeyError as e:
             fp.write(json.dumps(requests_log))
-            raise AssertionError(u"*** 未找到url！ Can't find the url you set! ***")
+            raise KeyError(u"*** 未找到url！ Can't find the url you set! ***")
